from src.cdfwriter.interface import CDFWriter
from .common_functions import (create_cdf_instance)
import datetime

def test_setDoNotSplit():

    cdf = create_cdf_instance()

    cdf.setDoNotSplit(True)
    assert cdf._doNotSplit == True

def test_setDoNotSplitBadArgument():

    # This test is for bad input data type - raises TypeError exception

    cdf = create_cdf_instance()

    cdf.setDoNotSplit(25)
    assert cdf._doNotSplit == 25

def test_setDoNotSplitBadFileBoundary():

    cdf = create_cdf_instance()

    cdf.setDoNotSplit(False, "timeDelta")
    assert cdf._boundary == "timeDelta"

def test_setDoNotSplitFileBoundary():

    cdf = create_cdf_instance()

    new_boundary = datetime.timedelta(hours=1)
    default_boundary = datetime.timedelta(hours=6)

    cdf.setDoNotSplit(False, new_boundary)
    assert cdf._boundary == new_boundary       #  This works
    assert cdf._boundary == default_boundary   # This fails



from src.cdfwriter.interface import CDFWriter
from .common_functions import (create_cdf_instance, create_global_attribute_list)

def test_addGlobalAttribute():

    cdf = create_cdf_instance()

    cdf.addGlobalAttribute ('Discipline', "Space Physics>Magnetospheric Science")

    list_of_global_attributes = create_global_attribute_list(cdf)

    assert 'Discipline' in list_of_global_attributes

def test_addGlobalAttributeBadArgument():

    # This test is for bad input data type - raises TypeError exception

    cdf = create_cdf_instance()

    cdf.addGlobalAttribute (25, "Space Physics>Magnetospheric Science")

    list_of_global_attributes = create_global_attribute_list(cdf)

    assert 25 in list_of_global_attributes

def test_addGlobalAttributeMissingData():

    # This test is to make sure data matches what was set.

    cdf = create_cdf_instance()

    cdf.addGlobalAttribute ('Discipline', "Space Physics>Magnetospheric Science")

    for name, value in cdf._global_attrs.items():
        if name == 'Discipline':
            assert 'Space Physics>Magnetospheric Science' == value  # This works
            assert 'Global Attribute Value Mismatch' == value



from src.cdfwriter.interface import CDFWriter
from .common_functions import (create_cdf_instance, create_variable_name_list)
from spacepy import pycdf

def test_addVariable():

    cdf = create_cdf_instance()

    cdf.addVariable("Epoch", pycdf.const.CDF_TIME_TT2000)

    list_of_all_variable_names = create_variable_name_list(cdf)

    # No need to check for empty list
    # raises an excepion IF the expression is false

    assert 'Epoch' in list_of_all_variable_names

def test_addVariableBadArgument():

    cdf = create_cdf_instance()

    # This test is for bad input data type - raises TypeError exception
    # Currently, only 1 argument is tested for validity.

    cdf.addVariable(25, pycdf.const.CDF_TIME_TT2000)

    list_of_all_variable_names = create_variable_name_list(cdf)

    # No need to check for empty list
    # raises an excepion IF the expression is false

    assert 25 in list_of_all_variable_names

def test_addVariableCaseSensitive():

    cdf = create_cdf_instance()

    cdf.addVariable('Epoch', pycdf.const.CDF_TIME_TT2000)

    list_of_all_variable_names = create_variable_name_list(cdf)

    # causes this module to fail

    assert 'epoch' in list_of_all_variable_names

def test_addVariableUndefinedVariable():

    cdf = create_cdf_instance()

    cdf.addVariable('Epoch', pycdf.const.CDF_TIME_TT2000)

    list_of_all_variable_names = create_variable_name_list(cdf)

    # causes this module to fail

    assert 'MissingVariable' in list_of_all_variable_names



from src.cdfwriter.interface import CDFWriter
from .common_functions import (create_cdf_instance)

def test_setVersionNumber():

    cdf = create_cdf_instance()

    cdf.setVersionNumber('4.2.0')
    assert cdf._version == "4.2.0"

def test_setVersionNumberBadArgument():
    # This test is for bad input data type - raises TypeError exception

    cdf = create_cdf_instance()

    cdf.setVersionNumber(25)
    assert cdf._version == 25

def test_setVersionNumberBadLevels():
    # Version Number expects 3 levels - raises ValueError exception

    cdf = create_cdf_instance()

    cdf.setVersionNumber('4.2')
    assert cdf._version == "4.2"

def test_setVersionNumberBadDataType():
    # Another test for bad input - raises TypeError exception

    cdf = create_cdf_instance()

    cdf.setVersionNumber('a.b.c')
    assert cdf._version == "a.b.c"

def test_setVersionNumberWrongVersion():

    cdf = create_cdf_instance()

    cdf.setVersionNumber('4.2.0')
    assert cdf._version == "4.1.0"




from src.cdfwriter.interface import CDFWriter
from .common_functions import (create_cdf_instance)

def test_setOutputDirectory():

    cdf = create_cdf_instance()

    cdf.setOutputDirectory ('/home/cgonzalez/MERIT/data_files/')
    assert cdf._outputDirectory == "/home/cgonzalez/MERIT/data_files/"

def test_setOutputDirectoryBadArgument():

    # This test is for bad input data type - raises TypeError exception

    cdf = create_cdf_instance()

    cdf.setOutputDirectory(25)
    assert cdf._outputDirectory == "25/"

def test_setOutputDirectoryWrongOutputDirectory():

    # Since setOutputDirectory will append a '/' character at the end
    # if there is not one already there, this test will fail on comparison.

    cdf = create_cdf_instance()

    cdf.setOutputDirectory ('/home/cgonzalez/MERIT/data_files')
    assert cdf._outputDirectory == "/home/cgonzalez/MERIT/data_files"



from src.cdfwriter.interface import CDFWriter
from .common_functions import (create_cdf_instance, create_constant_data_name_list)
from spacepy import pycdf
import numpy as np

def test_addConstantData():

    cdf = create_cdf_instance()

    cdf.addConstant ("HELIUM_ENERGY", pycdf.const.CDF_FLOAT, [11])
    cdf.addConstantData ("HELIUM_ENERGY", [7.1, 10, 14, 19.6, 27.4, 38.4, 53.4, 74.8, 104.7, 146.6, 205.2])

    list_of_all_constant_data_names = create_constant_data_name_list(cdf)

    # No need to check for empty list
    # raises an excepion IF the expression is false

    assert 'HELIUM_ENERGY' in list_of_all_constant_data_names

def test_addConstantDataBadArgument():

    cdf = create_cdf_instance()

    # This test is for bad input data type - raises TypeError exception
    # Currently, only 1 argument is tested for validity, not the data.

    cdf.addConstant ("HELIUM_ENERGY", pycdf.const.CDF_FLOAT, [11])
    cdf.addConstantData (25, [7.1, 10, 14, 19.6, 27.4, 38.4, 53.4, 74.8, 104.7, 146.6, 205.2])

    list_of_all_constant_data_names = create_constant_data_name_list(cdf)

    # No need to check for empty list
    # raises an excepion IF the expression is false

    assert 25 in list_of_all_constant_data_names

def test_addConstantDataCaseSensitive():

    cdf = create_cdf_instance()

    cdf.addConstant ("HELIUM_ENERGY", pycdf.const.CDF_FLOAT, [11])
    cdf.addConstantData ("helium_energy", [7.1, 10, 14, 19.6, 27.4, 38.4, 53.4, 74.8, 104.7, 146.6, 205.2])

    list_of_all_constant_data_names = create_constant_data_name_list(cdf)

    # causes this module to fail

    assert 'helium_energy' in list_of_all_constant_data_names

def test_addConstantDataUndefinedData():

    cdf = create_cdf_instance()

    cdf.addConstant ("HELIUM_ENERGY", pycdf.const.CDF_FLOAT, [11])
    cdf.addConstantData ("MISSING_CONSTANT", [7.1, 10, 14, 19.6, 27.4, 38.4, 53.4, 74.8, 104.7, 146.6, 205.2])

    list_of_all_constant_data_names = create_constant_data_name_list(cdf)

    # causes this module to fail

    assert 'MISSING_CONSTANT' in list_of_all_constant_data_names

def test_addConstantDataNotFound():

    cdf = create_cdf_instance()

    cdf.addConstant ("HELIUM_ENERGY", pycdf.const.CDF_FLOAT, [11])
    cdf.addConstantData ("HELIUM_ENERGY", [7.1, 10, 14, 19.6, 27.4, 38.4, 53.4, 74.8, 104.7, 146.6, 205.2])
    cdf.addConstant ("FAKE_ENERGY", pycdf.const.CDF_FLOAT, [11])
    cdf.addConstantData ("FAKE_ENERGY", [107.1, 110, 114, 119.6, 127.4, 138.4, 153.4, 174.8, 204.7, 246.6, 305.2])

    # This returns a list with one element, namely itself

    data_values = cdf._constantData.get("FAKE_ENERGY")

    fake_list = data_values[0]
    assert 107.1 in fake_list    # This passes
    assert 7.1 in fake_list      # This fails



from src.cdfwriter.interface import CDFWriter
from .common_functions import (create_cdf_instance, create_constant_name_list)
from spacepy import pycdf

def test_addConstant():

    cdf = create_cdf_instance()

    cdf.addConstant ("HELIUM_ENERGY", pycdf.const.CDF_FLOAT, [11])

    list_of_all_constant_names = create_constant_name_list(cdf)

    # No need to check for empty list
    # raises an excepion IF the expression is false

    assert 'HELIUM_ENERGY' in list_of_all_constant_names

def test_addConstantBadArgument():

    cdf = create_cdf_instance()

    # This test is for bad input data type - raises TypeError exception
    # Currently, only 1 argument is tested for validity.

    cdf.addConstant (25, pycdf.const.CDF_FLOAT, [11])

    list_of_all_constant_names = create_constant_name_list(cdf)

    # No need to check for empty list
    # raises an excepion IF the expression is false

    assert 25 in list_of_all_constant_names

def test_addConstantCaseSensitive():

    cdf = create_cdf_instance()

    cdf.addConstant ("HELIUM_ENERGY", pycdf.const.CDF_FLOAT, [11])

    list_of_all_constant_names = create_constant_name_list(cdf)

    # causes this module to fail

    assert 'helium_energy' in list_of_all_constant_names

def test_addConstantUndefinedConstant():

    cdf = create_cdf_instance()

    cdf.addConstant ("HELIUM_ENERGY", pycdf.const.CDF_FLOAT, [11])

    list_of_all_constant_names = create_constant_name_list(cdf)

    # causes this module to fail

    assert 'MissingConstant' in list_of_all_constant_names



from src.cdfwriter.interface import CDFWriter
from .common_functions import (create_cdf_instance, create_variable_data_name_list)
from spacepy import pycdf
import numpy as np

def test_addVariableData():

    cdf = create_cdf_instance()

    cdf.addVariable ("VECT_X_DATA", pycdf.const.CDF_INT4, [30])
    x_vector = np.zeros ((30), dtype=pycdf.const.CDF_INT4)
    for which in range (0, 30):
        x_vector [which] = which
    cdf.addVariableData ("VECT_X_DATA", x_vector)

    list_of_all_variable_data_names = create_variable_data_name_list(cdf)

    # No need to check for empty list
    # raises an excepion IF the expression is false

    assert 'VECT_X_DATA' in list_of_all_variable_data_names

def test_addVariableDataBadNameArgument():

    cdf = create_cdf_instance()

    # This test is for bad input data type - raises TypeError exception
    # Currently, only 1 argument is tested for validity, not the data.

    cdf.addVariable ("VECT_X_DATA", pycdf.const.CDF_INT4, [30])
    x_vector = np.zeros ((30), dtype=pycdf.const.CDF_INT4)
    for which in range (0, 30):
        x_vector [which] = which
    cdf.addVariableData (25, x_vector)

    list_of_all_variable_data_names = create_variable_data_name_list(cdf)

    # No need to check for empty list
    # raises an excepion IF the expression is false

    assert 25 in list_of_all_variable_data_names

def test_addVariableDataBadLastArgument():

    cdf = create_cdf_instance()

    # This test is for bad input data type - raises TypeError exception
    # Currently, only 1 argument is tested for validity, not the data.

    cdf.addVariable ("VECT_X_DATA", pycdf.const.CDF_INT4, [30])
    x_vector = np.zeros ((30), dtype=pycdf.const.CDF_INT4)
    for which in range (0, 30):
        x_vector [which] = which

    # works - cdf.addVariableData ("VECT_X_DATA", x_vector, False)
    cdf.addVariableData ("VECT_X_DATA", x_vector, "False")

    list_of_all_variable_data_names = create_variable_data_name_list(cdf)

    # No need to check for empty list
    # raises an excepion IF the expression is false

    assert "VECT_X_DATA" in list_of_all_variable_data_names

def test_addVariableDataCaseSensitive():

    cdf = create_cdf_instance()

    cdf.addVariable ("VECT_X_DATA", pycdf.const.CDF_INT4, [30])
    x_vector = np.zeros ((30), dtype=pycdf.const.CDF_INT4)
    for which in range (0, 30):
        x_vector [which] = which
    cdf.addVariableData ("vect_x_data", x_vector)

    list_of_all_variable_data_names = create_variable_data_name_list(cdf)

    # causes this module to fail

    assert 'vect_x_data' in list_of_all_variable_data_names

def test_addVariableDataUndefinedData():

    cdf = create_cdf_instance()

    cdf.addVariable ("VECT_X_DATA", pycdf.const.CDF_INT4, [30])
    x_vector = np.zeros ((30), dtype=pycdf.const.CDF_INT4)
    for which in range (0, 30):
        x_vector [which] = which
    cdf.addVariableData ("MISSING_VARIABLE", x_vector)

    list_of_all_variable_data_names = create_variable_data_name_list(cdf)

    # causes this module to fail

    assert 'MISSING_VARIABLE' in list_of_all_variable_data_names

def test_addVariableDataNotFound():

    cdf = create_cdf_instance()

    cdf.addVariable ("VECT_X_DATA", pycdf.const.CDF_INT4, [30])
    x_vector = np.zeros ((30), dtype=pycdf.const.CDF_INT4)
    for which in range (0, 30):
        x_vector [which] = which
    cdf.addVariableData ("VECT_X_DATA", x_vector)

    # This returns a list with one element, namely itself

    data_values = cdf._data.get("VECT_X_DATA")

    data_list = data_values[0]
    assert 7 in data_list    #  This works
    assert 35 in data_list   #  This fails
